using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;

namespace k.Frame.Utility
{
    public abstract class Formatter
    {
        private static System.Globalization.CultureInfo ci = System.Globalization.CultureInfo.GetCultureInfo("en-US");
        private static System.Globalization.CultureInfo tr = System.Globalization.CultureInfo.GetCultureInfo("tr-TR");

        private static string dNamesStrTR = "Pazar,pazartesi,Sal,aramba,Perembe,Cuma,Cumartesi";
        private static string mNamesStrTR = "Ocak,ubat,Mart,Nisan,Mays,Haziran,Temmuz,Austos,Eyll,Ekim,Kasm,Aralk";

        private static string dNamesStrEN = "Sunday,Monday,Tuesday,Wednesday,Thursday,Friday,Saturday";
        private static string mNamesStrEN = "January,February,March,April,May,June,July,August,September,October,November,December";

        #region FORMAT PHONE NUMBER
        public static string FormatPhoneNumber(string Number, bool HasPrefix)
        {
            return "";
        }
        #endregion

        #region FORMAT CURRENCY

        public static string FormatCurrency(decimal amount, int nDigits)
        {
            string digitFormatter = "#,##0." + "".PadRight(nDigits, '0');
            return Math.Round(amount, nDigits, MidpointRounding.AwayFromZero).ToString(digitFormatter, ci);
        }

        #endregion

        #region FORMAT RATE
        public static string FormatRate(string rate)
        {
            string separator = System.Globalization.NumberFormatInfo.CurrentInfo.CurrencyDecimalSeparator;
            string separatorToChange = ((separator == ".") ? "," : ".");
            return FormatRate(Convert.ToDecimal(rate.Replace(separatorToChange, separator)));
        }

        public static string FormatRate(string languageCode, decimal rate)
        {
            return languageCode == "TR" ? "% " + rate.ToString("0.00", ci) : rate.ToString("0.00", ci) + " %";
        }

        public static string FormatRate(decimal rate)
        {
            return FormatRate("TR", rate);
        }
        #endregion

        #region CONVERT TO DECIMAL
        public static decimal ConvertToDecimal(string amount)
        {
            return decimal.Parse(amount.PadLeft(1, '0'), System.Globalization.NumberStyles.Number, ci);
        }
        #endregion

        #region FORMAT CREDIT CARD NUMBER
        public static string FormatCreditCardNumber(string CreditCardNo)
        {
            string cc = CreditCardNo.Substring(0, 4) + "-" + CreditCardNo.Substring(4, 4) + "-" + CreditCardNo.Substring(8, 4) + "-" + CreditCardNo.Substring(12, 4);
            return cc;
        }
        #endregion

        #region MASK
        #endregion

        #region FORMAT DATE
        public static DateTime FormatDateWithCulture(DateTime Date)
        {
            System.Globalization.DateTimeFormatInfo dtfi = tr.DateTimeFormat;
            return DateTime.Parse(Date.ToString(), tr);
        }

        public static DateTime FormatDateWithCulture(string Date)
        {
            System.Globalization.DateTimeFormatInfo dtfi = tr.DateTimeFormat;
            return DateTime.Parse(Date, tr);
        }

        public static string FormatDateFromString(string res, bool withDayName)
        {
            if (res == "19000101")
                return "-";

            DateTime dt = new DateTime(Int16.Parse(res.Substring(0, 4)), Int16.Parse(res.Substring(4, 2)), Int16.Parse(res.Substring(6, 2)));
            return FormatDateFromString(dt, withDayName);
        }

        public static string FormatDateFromString(DateTime Date)
        {
            return FormatDateFromString(Date, false);
        }

        public static string FormatDateFromString(DateTime Date, bool WithDayName, System.Globalization.CultureInfo culture)
        {
            System.Globalization.DateTimeFormatInfo dtfi = culture.DateTimeFormat;
            if (WithDayName)
            {
                return Date.ToString(dtfi.ShortDatePattern) + ", " + dtfi.GetDayName(Date.DayOfWeek);
            }
            return Date.ToString(dtfi.ShortDatePattern);
        }

        public static string FormatDateFromString(DateTime Date, bool WithDayName)
        {
            return FormatDateFromString(Date, WithDayName, tr);
        }


        #endregion

        #region FORMAT SQL DATE
        public static string FormatSqlDate(string res, bool withDayName, bool withMonthName)
        {
            if (res == "19000101")
                return "-";

            string[] dNames = System.Globalization.CultureInfo.CurrentCulture.DateTimeFormat.DayNames;
            string[] mNames = System.Globalization.CultureInfo.CurrentCulture.DateTimeFormat.MonthNames;
            DateTime dt = Convert.ToDateTime(res);
            string pDate = "";
            if (withMonthName)
                pDate = dt.Day.ToString().PadLeft(2, '0') + "." + mNames[int.Parse(dt.Month.ToString()) - 1] + "." + dt.Year.ToString().PadLeft(4, '0');
            else
                pDate = dt.Day.ToString().PadLeft(2, '0') + "." + dt.Month.ToString().PadLeft(2, '0') + "." + dt.Year.ToString().PadLeft(4, '0');

            int i = (int)dt.DayOfWeek;

            string pDateName = dNames[i];
            if (withDayName)
                return pDate + " - " + pDateName;
            else
                return pDate;

        }
        #endregion

    }
}
